#[repr(C)]pub struct DomainIsEnabledResponse {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for DomainIsEnabledResponse
impl Clone for DomainIsEnabledResponse
Sourcefn clone(&self) -> DomainIsEnabledResponse
fn clone(&self) -> DomainIsEnabledResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DomainIsEnabledResponse
impl Debug for DomainIsEnabledResponse
Sourceimpl<'a, ___E> Encode<DomainIsEnabledResponse, ___E> for &'a DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DomainIsEnabledResponse, ___E> for &'a DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DomainIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DomainIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DomainIsEnabledResponse, ___E> for DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DomainIsEnabledResponse, ___E> for DomainIsEnabledResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DomainIsEnabledResponse, DomainIsEnabledResponse>
const COPY_OPTIMIZATION: CopyOptimization<DomainIsEnabledResponse, DomainIsEnabledResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DomainIsEnabledResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DomainIsEnabledResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DomainIsEnabledResponse>, ___E> for &'a DomainIsEnabledResponse
impl<'a, ___E> EncodeOption<Box<'static, DomainIsEnabledResponse>, ___E> for &'a DomainIsEnabledResponse
Sourcefn encode_option(
this: Option<&'a DomainIsEnabledResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DomainIsEnabledResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DomainIsEnabledResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DomainIsEnabledResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DomainIsEnabledResponse>, ___E> for DomainIsEnabledResponse
impl<___E> EncodeOption<Box<'static, DomainIsEnabledResponse>, ___E> for DomainIsEnabledResponse
Sourcefn encode_option(
this: Option<DomainIsEnabledResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DomainIsEnabledResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DomainIsEnabledResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DomainIsEnabledResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DomainIsEnabledResponse> for DomainIsEnabledResponse
impl FromWire<DomainIsEnabledResponse> for DomainIsEnabledResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DomainIsEnabledResponse, DomainIsEnabledResponse>
const COPY_OPTIMIZATION: CopyOptimization<DomainIsEnabledResponse, DomainIsEnabledResponse>
Sourcefn from_wire(wire: DomainIsEnabledResponse) -> DomainIsEnabledResponse
fn from_wire(wire: DomainIsEnabledResponse) -> DomainIsEnabledResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DomainIsEnabledResponse> for DomainIsEnabledResponse
impl FromWireRef<DomainIsEnabledResponse> for DomainIsEnabledResponse
Sourcefn from_wire_ref(wire: &DomainIsEnabledResponse) -> DomainIsEnabledResponse
fn from_wire_ref(wire: &DomainIsEnabledResponse) -> DomainIsEnabledResponse
Converts the given reference to this type.
Sourceimpl Hash for DomainIsEnabledResponse
impl Hash for DomainIsEnabledResponse
Sourceimpl Ord for DomainIsEnabledResponse
impl Ord for DomainIsEnabledResponse
Sourcefn cmp(&self, other: &DomainIsEnabledResponse) -> Ordering
fn cmp(&self, other: &DomainIsEnabledResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DomainIsEnabledResponse
impl PartialEq for DomainIsEnabledResponse
Sourcefn eq(&self, other: &DomainIsEnabledResponse) -> bool
fn eq(&self, other: &DomainIsEnabledResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DomainIsEnabledResponse
impl PartialOrd for DomainIsEnabledResponse
impl Copy for DomainIsEnabledResponse
impl Eq for DomainIsEnabledResponse
impl StructuralPartialEq for DomainIsEnabledResponse